# Code of Conduct

## Our Pledge

We pledge to make participation in our community harassment-free for everyone.

## Our Standards

Positive behavior includes:
- Being respectful and inclusive
- Giving and accepting constructive feedback
- Focusing on what is best for the community

Unacceptable behavior includes:
- Harassment or discriminatory language
- Trolling or personal attacks
- Publishing private information
- Other unprofessional conduct

## Enforcement

Instances of abusive or unacceptable behavior may be reported to oss@tivision.dev.
All complaints will be reviewed and investigated promptly and fairly.

## Attribution

This Code of Conduct is adapted from the Contributor Covenant, version 2.1.
